@@ -37,6 +37,10 @@
  * The API is built upon the top of GIO's #GMount, #GDrive and #GVolume API.
  **/
 
+struct _TrackerStorage {
+	GObject parent_instance;
+};
+
 #define TRACKER_STORAGE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TRACKER_TYPE_STORAGE, TrackerStoragePrivate))
 
 typedef struct {
@@ -661,10 +665,9 @@ mount_add (TrackerStorage *storage,
 					g_debug ("  No UUID, generated:'%s' (based on mount path)", uuid);
 				} else {
 					g_debug ("  Being ignored because mount is music/video "
-					         "(content type:%s, optical:%s, multimedia:%s)",
+					         "(content type:%s, optical:%s, multimedia: yes)",
 					         content_type,
-					         is_optical ? "yes" : "no",
-					         is_multimedia ? "yes" : "no");
+					         is_optical ? "yes" : "no");
 				}
 
 				g_free (content_type);
