@@ -26,7 +26,6 @@ Monitor a test directory and copy/move/remove/update files and folders there.
 Check the basic data of the files is updated accordingly in tracker.
 """
 
-
 import itertools
 import logging
 import os
@@ -688,6 +687,141 @@ class MinerCrawlTest(fixtures.TrackerMinerTest):
         new_urn = self.__get_file_urn(dest)
         self.assertNotEqual(urn, new_urn)
 
+    def test_20_recover_corruption(self):
+        """
+        Trick a constraint corruption. See how it fares
+        """
+
+        # Insert a blank node with a nie:url
+        path = self.path("test-monitored/test.txt")
+        uri = self.uri("test-monitored/test.txt")
+        self.tracker.update(
+            "INSERT DATA { GRAPH tracker:FileSystem { _:u a nfo:FileDataObject ; nie:url '%s' } }" % uri)
+
+        pid = self.sandbox.session_bus.get_connection_unix_process_id_sync(
+            'org.freedesktop.LocalSearch3')
+
+        # Create a file on that url, see it fail
+        with open(path, "w") as f:
+            f.write(DEFAULT_TEXT)
+
+        # Ensure the process is gone
+        pid_exists = True
+        attempts = 0
+        while pid_exists:
+            if attempts == 10:
+                raise RuntimeError("Took too long for indexer to die")
+
+            try:
+                time.sleep(1)
+                program = os.readlink("/proc/" + str(pid) + "/exe")
+                pid_exists = os.path.basename(program) == "localsearch-3"
+                if pid_exists:
+                    attempts += 1
+            except:
+                pid_exists = False
+
+        # Restart the indexer
+        with self.await_document_inserted(path) as resource:
+            conn = self.miner_fs.get_sparql_connection()
+
+        result = self.__get_text_documents()
+        unpacked_result = [r[0] for r in result]
+        self.assertIn(self.uri("test-monitored/test.txt"), unpacked_result)
+        self.assertIn(self.uri("test-monitored/file1.txt"), unpacked_result)
+        self.assertIn(self.uri("test-monitored/dir1/file2.txt"), unpacked_result)
+        self.assertIn(self.uri("test-monitored/dir1/dir2/file3.txt"), unpacked_result)
+        self.assertEqual(len(result), 4)
+
+    def test_21_move_directory_from_hidden_to_visible_and_back(self):
+        """
+        Move a directory from unmonitored to monitored, and back
+        """
+        file = self.path("test-monitored/.dir/file.txt")
+        dest_file = self.path("test-monitored/dir/file2.txt")
+        source = self.path("test-monitored/.dir")
+        dest = self.path("test-monitored/dir")
+
+        os.mkdir(source)
+        with open(file, "w") as f:
+            f.write(DEFAULT_TEXT)
+
+        with self.await_document_inserted(self.path("test-monitored/dir/file.txt")):
+            os.rename(source, dest)
+
+        result = self.__get_text_documents()
+        # Default test data, plus the new file
+        self.assertEqual(len(result), 4)
+        unpacked_result = [r[0] for r in result]
+        self.assertIn(self.uri("test-monitored/dir/file.txt"), unpacked_result)
+
+        file_id = self.tracker.get_content_resource_id(self.uri("test-monitored/dir/file.txt"))
+        with self.tracker.await_delete(
+            fixtures.DOCUMENTS_GRAPH, file_id, timeout=cfg.AWAIT_TIMEOUT
+        ):
+            os.rename(dest, source)
+
+        result = self.__get_text_documents()
+        # Default test data only
+        self.assertEqual(len(result), 3)
+        unpacked_result = [r[0] for r in result]
+        self.assertIn(self.uri("test-monitored/file1.txt"), unpacked_result)
+
+    def test_22_move_directory_from_hidden_to_visible_and_back_interrupted(self):
+        """
+        Move a directory from unmonitored to monitored, and back, but
+        ensure the crawling operation is interrupted
+        """
+        file = self.path("test-monitored/.dir/file.txt")
+        dest_file = self.path("test-monitored/dir/file2.txt")
+        source = self.path("test-monitored/.dir")
+        subdir = self.path("test-monitored/.dir/subdir")
+        dest = self.path("test-monitored/dir")
+
+        # Queue a substantial amount of changes, so there's larger guarantees
+        N_FILES = 5000
+
+        # Create a file to detect that the directory was moved
+        os.mkdir(source)
+        with open(file, "w") as f:
+            f.write(DEFAULT_TEXT)
+
+        # Add a decent amount of files in a subdir
+        os.mkdir(subdir)
+        for i in range(N_FILES):
+            text_file = os.path.join(subdir, "file-%d" % i)
+            with open(text_file, "w") as f:
+                f.write(DEFAULT_TEXT)
+
+        # Rename the dir and expect our canary file to be indexed
+        # This should still be in the middle of operations, since
+        # a subdir with enough amount of data has to be crawled
+        check_file = self.uri("test-monitored/dir/file.txt")
+        with self.tracker.await_insert(
+            fixtures.FILESYSTEM_GRAPH, f"nie:url <{check_file}>", timeout=cfg.AWAIT_TIMEOUT
+        ):
+            os.rename(source, dest)
+
+        # Avoid checks to ensure the indexer didn't complete
+
+        file_id = self.tracker.get_content_resource_id(self.uri("test-monitored/dir"))
+        with self.tracker.await_delete(
+            fixtures.FILESYSTEM_GRAPH, file_id, timeout=cfg.AWAIT_TIMEOUT
+        ):
+            os.rename(dest, source)
+
+        result = self.__get_text_documents()
+        # Default test data only
+        self.assertEqual(len(result), 3)
+        unpacked_result = [r[0] for r in result]
+        self.assertIn(self.uri("test-monitored/file1.txt"), unpacked_result)
+
+        # Wait a bit and repeat the same checks
+        time.sleep(3)
+        result = self.__get_text_documents()
+        self.assertEqual(len(result), 3)
+        unpacked_result = [r[0] for r in result]
+        self.assertIn(self.uri("test-monitored/file1.txt"), unpacked_result)
 
 class IndexedFolderTest(fixtures.TrackerMinerTest):
     """
